summaryrefslogtreecommitdiffstats
path: root/manualtesting/manual_testing.go
diff options
context:
space:
mode:
Diffstat (limited to 'manualtesting/manual_testing.go')
-rw-r--r--manualtesting/manual_testing.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/manualtesting/manual_testing.go b/manualtesting/manual_testing.go
index 3c2289626..ffdb578a4 100644
--- a/manualtesting/manual_testing.go
+++ b/manualtesting/manual_testing.go
@@ -16,7 +16,7 @@ import (
"time"
)
-type TestEnviroment struct {
+type TestEnvironment struct {
Params map[string][]string
Client *model.Client
CreatedTeamId string
@@ -121,8 +121,8 @@ func manualTest(c *api.Context, w http.ResponseWriter, r *http.Request) {
http.Redirect(w, r, "/channels/town-square", http.StatusTemporaryRedirect)
}
- // Setup test enviroment
- env := TestEnviroment{
+ // Setup test environment
+ env := TestEnvironment{
Params: params,
Client: client,
CreatedTeamId: teamID,